@@ -56,17 +56,6 @@ gads_get_report_helper <- function(
             tolower() %>%
             str_c(collapse = ', ')
 
-  # test for selectble with date fields
-  selectable <- suppressMessages( gads_get_fields_cached(resource)$selectableWith )
-
-  # where block
-  if (! "segments.date" %in% selectable ) {
-    date_from <- NULL
-    date_to   <- NULL
-    during    <- NA
-    cli_alert_warning('fields values of date_from, date_to and during was unset automatically, because it is not selectable with {resource}')
-  }
-
   if ( any(is.null(date_from), is.null(date_to)) & is.null(where) ) {
     where_clause <- ""
   } else if ( !is.na(during) ) {
